@@ -25,9 +25,11 @@ import tarfile
 import tempfile
 import zipfile
 from datetime import datetime, timedelta
+from pathlib import Path
 from time import sleep
-from typing import TYPE_CHECKING, Any, Callable, Optional, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Callable, Literal, Optional, TypeVar, Union
 
+from eodag.api.product.metadata_mapping import ONLINE_STATUS
 from eodag.plugins.base import PluginTopic
 from eodag.utils import (
     DEFAULT_DOWNLOAD_TIMEOUT,
@@ -132,7 +134,8 @@ class Download(PluginTopic):
         self,
         product: EOProduct,
         auth: Optional[Union[AuthBase, S3SessionKwargs]] = None,
-        progress_callback: Optional[ProgressCallback] = None,
+        byte_range: tuple[Optional[int], Optional[int]] = (None, None),
+        compress: Literal["zip", "raw", "auto"] = "auto",
         wait: float = DEFAULT_DOWNLOAD_WAIT,
         timeout: float = DEFAULT_DOWNLOAD_TIMEOUT,
         **kwargs: Unpack[DownloadConf],
@@ -231,12 +234,23 @@ class Download(PluginTopic):
         )
         if os.path.isfile(old_record_filename):
             os.rename(old_record_filename, record_filename)
-        if os.path.isfile(record_filename) and os.path.isfile(fs_path):
+
+        # path with or without extension
+        path_obj = Path(fs_path)
+        matched_paths = list(path_obj.parent.glob(f"{path_obj.stem}.*"))
+        fs_path_with_ext = matched_paths[0] if matched_paths else fs_path
+        if (
+            os.path.isfile(record_filename)
+            and fs_path_with_ext
+            and os.path.isfile(fs_path_with_ext)
+        ):
             logger.info(
-                f"Product already downloaded: {fs_path}",
+                f"Product already downloaded: {fs_path_with_ext}",
             )
             return (
-                self._finalize(fs_path, progress_callback=progress_callback, **kwargs),
+                self._finalize(
+                    str(fs_path_with_ext), progress_callback=progress_callback, **kwargs
+                ),
                 None,
             )
         elif os.path.isfile(record_filename) and os.path.isdir(fs_dir_path):
@@ -600,15 +614,21 @@ class Download(PluginTopic):
                     if datetime_now >= product.next_try:
                         product.next_try += timedelta(minutes=wait)
                         try:
-                            return order_download(*args, **kwargs)
-
+                            download = order_download(*args, **kwargs)
                         except NotAvailableError as e:
-                            if not getattr(self.config, "order_enabled", False):
-                                raise NotAvailableError(
-                                    f"Product is not available for download and order is not supported for"
-                                    f" {self.provider}, {e}"
-                                )
                             not_available_info = str(e)
+                        else:
+                            if (
+                                product.properties.get("storageStatus", ONLINE_STATUS)
+                                == ONLINE_STATUS
+                            ) or timeout <= 0:
+                                return download
+
+                        if not getattr(self.config, "order_enabled", False):
+                            raise NotAvailableError(
+                                f"Product is not available for download and order is not supported for"
+                                f" {self.provider}, {not_available_info}"
+                            )
 
                     if datetime_now >= product.next_try and datetime_now < stop_time:
                         wait_seconds: Union[float, int] = (
