@@ -149,7 +149,8 @@ class TestDownloadPluginBase(BaseDownloadPluginTest):
 
             # < v3.0.0b1 formatted record file and product path exist, record file moved to new format
             product_path_dir.mkdir()
-            (product_path_dir / "foo").touch()
+            file_in_dir = product_path_dir / "foo"
+            file_in_dir.touch()
             old_recordfile_path.touch()
             with self.assertLogs(level="INFO") as cm:
                 plugin._prepare_download(self.product, **download_kwargs)
@@ -163,6 +164,24 @@ class TestDownloadPluginBase(BaseDownloadPluginTest):
                 self.assertTrue(os.path.isfile(recordfile_path))
                 self.assertIn("Product already downloaded", str(cm.output))
 
+            # already downloaded product without extension
+            file_in_dir.unlink()
+            product_path_dir.rmdir()
+            product_path_dir.touch()
+            with self.assertLogs(level="INFO") as cm:
+                plugin._prepare_download(self.product, **download_kwargs)
+                self.assertIn("Product already downloaded", str(cm.output))
+                self.assertIn(
+                    "Remove existing partially downloaded file", str(cm.output)
+                )
+
+            # already downloaded product with extension
+            product_path_with_ext = product_path_dir.with_suffix(".xyz")
+            product_path_with_ext.touch()
+            with self.assertLogs(level="INFO") as cm:
+                plugin._prepare_download(self.product, **download_kwargs)
+                self.assertIn("Product already downloaded", str(cm.output))
+
     def test_plugins_download_base_prepare_download_no_url(self):
         """Download._prepare_download must return None when no download url"""
 
@@ -270,6 +289,7 @@ class TestDownloadPluginHttp(BaseDownloadPluginTest):
         )
         dl_config = config.PluginConfig.from_mapping(
             {
+                "type": "HTTPDownload",
                 "base_uri": "fake_base_uri",
                 "output_dir": self.output_dir,
                 "extract": False,
@@ -1798,13 +1818,16 @@ class TestDownloadPluginAws(BaseDownloadPluginTest):
         """AwsDownload.download() must handle files in zip"""
 
         def _open_zip(*args, **kwargs):
-            return zipfile.ZipFile(
-                os.path.join(
-                    TEST_RESOURCES_PATH,
-                    "products",
-                    "as_archive",
-                    "S2A_MSIL1C_20180101T105441_N0206_R051_T31TDH_20180101T124911.zip",
-                )
+            return (
+                zipfile.ZipFile(
+                    os.path.join(
+                        TEST_RESOURCES_PATH,
+                        "products",
+                        "as_archive",
+                        "S2A_MSIL1C_20180101T105441_N0206_R051_T31TDH_20180101T124911.zip",
+                    )
+                ),
+                b"",
             )
 
         mock_open_s3_zipped_object.side_effect = _open_zip
